@@ -23,7 +23,6 @@
 PG_FUNCTION_INFO_V1(nvarchar2in);
 PG_FUNCTION_INFO_V1(nvarchar2out);
 PG_FUNCTION_INFO_V1(nvarchar2);
-PG_FUNCTION_INFO_V1(nvarchar2typmodin);
 PG_FUNCTION_INFO_V1(nvarchar2recv);
 
 /*
@@ -155,7 +154,7 @@ nvarchar2(PG_FUNCTION_ARGS)
 	bool		isExplicit = PG_GETARG_BOOL(2);
 	int32		len,
 				maxlen;
-	size_t		maxmblen;
+	int		maxmblen;
 	char		*s_data;
 
 	len = VARSIZE_ANY_EXHDR(source);
