@@ -3,7 +3,7 @@
   free available library PL/Vision. Please look www.quest.com
 
   Original author: Steven Feuerstein, 1996 - 2002
-  PostgreSQL implementation author: Pavel Stehule, 2006
+  PostgreSQL implementation author: Pavel Stehule, 2006-2018
 
   This module is under BSD Licence
 
@@ -28,7 +28,6 @@
 
 PG_FUNCTION_INFO_V1(plvstr_rvrs);
 PG_FUNCTION_INFO_V1(plvstr_normalize);
-PG_FUNCTION_INFO_V1(plvstr_is_prefix);
 PG_FUNCTION_INFO_V1(plvstr_is_prefix_text);
 PG_FUNCTION_INFO_V1(plvstr_is_prefix_int);
 PG_FUNCTION_INFO_V1(plvstr_is_prefix_int64);
@@ -302,7 +301,18 @@ plvstr_normalize(PG_FUNCTION_ARGS)
 	text *str = PG_GETARG_TEXT_PP(0);
 	text *result;
 	char *aux, *aux_cur;
-	int i, l;
+	int i;
+
+#if defined(_MSC_VER) && (defined(_M_X64) || defined(__amd64__))
+
+	__int64			l;
+
+#else
+
+	int				l;
+
+#endif
+
 	char c, *cur;
 	bool write_spc = false;
 	bool ignore_stsp = true;
