@@ -27,7 +27,7 @@ typedef struct {
 
 typedef struct {
 	int list_c;
-	int max_size;
+	size_t max_size;
 	vardata data[1];	 /* flexible array member */
 } mem_desc;
 
@@ -66,7 +66,7 @@ ptr_comp(const void* a, const void* b)
 char *
 ora_sstrcpy(char *str)
 {
-	int len;
+	size_t len;
 	char *result;
 
 	len = strlen(str);
@@ -76,7 +76,7 @@ ora_sstrcpy(char *str)
 		ereport(ERROR,
 			(errcode(ERRCODE_OUT_OF_MEMORY),
 			errmsg("out of memory"),
-			errdetail("Failed while allocation block %d bytes in shared memory.", len+1),
+			errdetail("Failed while allocation block %d bytes in shared memory.", (int) len+1),
 			errhint("Increase SHMEMMSGSZ and recompile package.")));
 
 	return result;
@@ -99,7 +99,7 @@ ora_scstring(text *str)
 		ereport(ERROR,
 			(errcode(ERRCODE_OUT_OF_MEMORY),
 			errmsg("out of memory"),
-			errdetail("Failed while allocation block %d bytes in shared memory.", len+1),
+			errdetail("Failed while allocation block %d bytes in shared memory.", (int) len+1),
 			errhint("Increase SHMEMMSGSZ and recompile package.")));
 
 	return result;
