@@ -1,7 +1,7 @@
 -- Tests for package DBMS_RANDOM
 SELECT dbms_random.initialize(8);
-SELECT dbms_random.normal();
-SELECT dbms_random.normal();
+SELECT dbms_random.normal()::numeric(10, 8);
+SELECT dbms_random.normal()::numeric(10, 8);
 SELECT dbms_random.seed(8);
 SELECT dbms_random.random();
 SELECT dbms_random.seed('test');
@@ -11,6 +11,6 @@ SELECT dbms_random.string('x',4);
 SELECT dbms_random.string('a',2);
 SELECT dbms_random.string('l',3);
 SELECT dbms_random.seed(5);
-SELECT dbms_random.value();
-SELECT dbms_random.value(10,15);
+SELECT dbms_random.value()::numeric(10, 8);
+SELECT dbms_random.value(10,15)::numeric(10, 8);
 SELECT dbms_random.terminate();
