@@ -55,4 +55,8 @@ SELECT 'abcde   '::NVARCHAR2(10) = 'abcde   '::NVARCHAR2(10);
 -- not equal
 SELECT 'abcde  '::NVARCHAR2(10) = 'abcde   '::NVARCHAR2(10);
 
+-- null safe concat (disabled by default)
+SELECT NULL || 'hello'::varchar2 || NULL;
 
+SET orafce.varchar2_null_safe_concat TO true;
+SELECT NULL || 'hello'::varchar2 || NULL;
