@@ -3,7 +3,7 @@
   free available library PL/Vision. Please look www.quest.com
 
   Original author: Steven Feuerstein, 1996 - 2002
-  PostgreSQL implementation author: Pavel Stehule, 2006
+  PostgreSQL implementation author: Pavel Stehule, 2006-2018
 
   This module is under BSD Licence
 
@@ -120,7 +120,7 @@ dbms_utility_format_call_stack(char mode)
 
 				if ((p1 = strstr(start, "line ")))
 				{
-					int p2i;
+					size_t p2i;
 					char c;
 
 					p1 += strlen("line ");
